@@ -24,7 +24,7 @@ class DingTalkNotifyPlugin(CorePluginMixin, notify.NotificationPlugin):
     required_field = "webhook"
     author = "Mo"
     author_url = "https://github.com/M-Davinci/dt_notify_to_people"
-    version = "1.6.5"
+    version = "1.6.6"
     resource_links = [
         ("Report Issue", "https://github.com/M-Davinci/dt_notify_to_people/issues"),
         ("View Source", "https://github.com/M-Davinci/dt_notify_to_people"),
@@ -122,7 +122,9 @@ class DingTalkNotifyPlugin(CorePluginMixin, notify.NotificationPlugin):
         payload = f"{payload} > 全部报错: {group} \n\n"
         payload = f"{payload} > 全部报错: {group.__dict__} \n\n"
         payload = f"{payload} > 全部报错: {group.__dict__['_state'].__dict__} \n\n"
-        payload = f"{payload} > 全部报错: {group.__dict__['_state'].__dict__['fields_cache']['project'].__dict__} \n\n"
+        project_obj = group.__dict__['_state'].__dict__['fields_cache']['project'].__dict__
+        obj = json.loads(str(project_obj).replace("'", "\"").replace("True", '"True"').replace("False", '"False"'))
+        payload = f"{payload} > 阿明: {obj} \n\n"
 
         headers = {
             "Content-type": "application/json",
